/*
django-modeltranslation support
https://github.com/deschler/django-modeltranslation
*/

.admin-interface #content h1 select {
    text-transform: uppercase;
    margin-left: 15px;
    min-width: 50px;
}

.admin-interface .ui-tabs .ui-tabs-panel[id^=tab_id_] {
    border: none;
    border-top: 1px solid #eeeeee;
    padding: 0;
    margin-bottom: 0;
}
