{% load i18n admin_interface_tags %}

{% get_admin_interface_theme as theme %}

{% if theme.list_filter_dropdown %}

    {% include "admin_interface/dropdown_filter.html" %}

{% else %}

    {# Use the default list filter template -> https://github.com/django/django/blob/master/django/contrib/admin/templates/admin/filter.html #}

    <h3>{% blocktrans with filter_title=title %} By {{ filter_title }} {% endblocktrans %}</h3>
    <ul>
    {% for choice in choices %}
        <li{% if choice.selected %} class="selected"{% endif %}>
        <a href="{{ choice.query_string|iriencode }}">{{ choice.display }}</a></li>
    {% endfor %}
    </ul>

{% endif %}

