.admin-interface.login #container {
    width:320px;
    margin:90px auto;
    box-sizing:border-box;
    -moz-box-sizing:border-box;
    -webkit-box-sizing:border-box;
}

.admin-interface.login #content {
    padding:15px 30px 10px 30px;
}

@media (max-width:767px){

    .admin-interface.login #container {
        margin:0px auto;
    }

    .admin-interface.login #content {
        padding:20px 30px 30px 30px;
    }
}

.admin-interface.login #header {
    padding:15px 30px 10px;
    line-height:30px;
}

.admin-interface.login #branding h1 {
    margin-right:0;
}

.admin-interface.login #branding h1 img.logo {
    max-width:100%;
    margin-right:0;
}

.admin-interface.login #header #branding h1 img.logo+span {
    display:block;
    margin-bottom: 5px;
}

.admin-interface.login .submit-row {
    padding-left:0;
    text-align:right;
}

@media (max-width:767px){
    .admin-interface.login .submit-row label {
        display:none;
    }
    .admin-interface.login .submit-row {
        float: left;
        width: 100%;
        margin-top: 20px;
        margin-bottom: 30px;
    }
}

.admin-interface #header {
    height:auto;
    min-height:40px;
}

.admin-interface #branding h1 img.logo {
    max-height:100px;
    margin-top:10px;
    margin-bottom:10px;
    margin-right:15px;
    display:inline-block !important; /* override inline display:none; */
}

.admin-interface #branding h1 img.logo+span {
    white-space:nowrap;
}

.admin-interface fieldset.collapse {
    border: 1px solid transparent;
}

.admin-interface fieldset.collapse.collapsed a.collapse-toggle,
.admin-interface fieldset.collapse a.collapse-toggle {
    font-weight: normal;
    text-transform: lowercase;
    font-size: 12px;
    text-decoration: underline;
    padding: 0 1px;
}

/*
#changelist table tbody tr.selected {
    background-color:#FFFFCC;
}
*/

.admin-interface #changelist .paginator {
    margin-top:-1px; /* merge 2 borders into 1 */
    line-height:42px;
}

.admin-interface .paginator a,
.admin-interface .paginator a:link,
.admin-interface .paginator a:visited,
.admin-interface .paginator .this-page {
    padding:7px 12px;
}

.admin-interface .paginator a,
.admin-interface .paginator .this-page {
    margin-left:0px;
}

.admin-interface .paginator .this-page,
.admin-interface .paginator a.end {
    margin-right:25px;
}

.admin-interface .paginator .this-page + a:not(.showall)  {
    margin-left:-25px;
}

body.admin-interface .paginator a.showall,
body.admin-interface .paginator a.showall:link,
body.admin-interface .paginator a.showall:visited {
    margin-left:20px;
}

/* fix help text icon on newline */
.admin-interface .inline-group thead th {
    white-space:nowrap;
}

.admin-interface .inline-group thead th img {
    vertical-align: -2px;
    margin-left: 5px;
}

.admin-interface .file-thumbnail > a {
    display: inline-block;
}

.admin-interface .aligned p.file-upload {
    display:table;
}

.admin-interface form .form-row p.file-upload > a {
    margin-right:20px;
}

.admin-interface form .form-row p.file-upload .clearable-file-input {
    display:inline-block;
    margin-left:
}

.admin-interface form .form-row p.file-upload .clearable-file-input label {
    padding-bottom:0px;
    margin-left:2px;
}

.admin-interface form .form-row p.file-upload > input[type="file"] {
    margin-top: 0px;
}

@media (max-width:767px){

    .admin-interface form .form-row p.file-upload {
        width: 100%;
    }

    .admin-interface form .form-row p.file-upload > a {
        margin-right:0px;
        display: block;
        white-space: pre-wrap;
        word-break: break-word;
    }

    .admin-interface form .form-row p.file-upload .clearable-file-input {
        display: block;
        margin-top: 10px;
        margin-bottom: -10px;
    }

    .admin-interface form .form-row p.file-upload > input[type="file"] {
        display: block;
        width: auto;
        padding: 0px;
    }

    /* fix inline horizontal scroll caused by checkbox-row */
    .admin-interface form .form-row > div.checkbox-row {
        width: 100%;
    }
}


/* FIX WIDE FIELDSET HELPS / ERROR MESSAGES */
.admin-interface form .wide p.help,
.admin-interface form .wide div.help {
    padding-left: 50px;
}

.admin-interface form .wide input + p.help,
.admin-interface form .wide input + div.help {
    margin-left: 160px;
}

@media (max-width:767px){
    .admin-interface form .form-row div.help {
        display: block;
        width: 100%;
    }
}

.admin-interface form .wide ul.errorlist {
    margin-left: 200px;
}

/* LIST FILTER */
.admin-interface .module.filtered h2 {
    border-bottom-left-radius:0;
    border-bottom-right-radius:0;
}

.admin-interface .module.filtered #changelist-filter {
    border-bottom-left-radius:4px;
    border-bottom-right-radius:4px;
}

.admin-interface .module.filtered #changelist-filter h2 {
    font-size: 11px;
    padding: 10px 15px;
}

/* begin fix issue #13 - Datetime widget broken in long inlines */
.admin-interface p.datetime {
    white-space:nowrap;
}
/* end fix */

/* begin fix lateral padding to align text with field labels */
.admin-interface .module h2,
.admin-interface.dashboard .module caption,
.admin-interface .module.filtered h2,
.admin-interface .inline-group h2 {
    padding-left:10px;
    padding-right:10px;
}
/* end fix */

/* begin fix restrict tabular-inline horizontal-scroll to inline-group instead of whole page */
.admin-interface .inline-group[data-inline-type="tabular"] {
    overflow-x:auto;
}
/* end fix */

/* begin fix stacked-inline margin-bottom in responsive small viewport */
.admin-interface .inline-group[data-inline-type="stacked"] .module {
    margin-bottom:0px;
}
/* end fix */

/* begin fix issue #10 - Related widget broken in long tabular inline */
.admin-interface .inline-group .tabular .related-widget-wrapper {
    white-space:nowrap;
}
/* end fix */

.admin-interface .inline-related h3 {
    padding:6px 10px;
}

/* begin fix issue #12 - Inlines bad delete buttons alignement */
.admin-interface .inline-group .tabular thead th:last-child:not([class]):not([style]) {
    text-align:right;
}

.admin-interface .inline-group .tabular tr td {
    vertical-align: top;
}

.admin-interface .inline-group .tabular tr td.delete {
    text-align:right;
    padding-right:15px;
    vertical-align: top;
}

.admin-interface .inline-group .tabular tr td input[type="checkbox"] {
    margin: 7px 0px;
}

.admin-interface .inline-group .tabular tr td.delete a.inline-deletelink {
    margin-top:4px;
    overflow:hidden;
    text-indent:9999px;
}
/* end fix */

/* top-right buttons color on hover -> just a lighten grey */
.admin-interface .object-tools a {
    color:#FFFFFF;
}
.admin-interface .object-tools a:focus,
.admin-interface .object-tools a:hover,
.admin-interface .object-tools li:focus a,
.admin-interface .object-tools li:hover a {
    background-color:#AAAAAA;
}

/* fix textarea horizontal scroll on Firefox */
@media (max-width: 767px){
    .admin-interface .aligned .form-row textarea {
        width: 100% !important;
        flex: 0 1 auto;
    }
    .admin-interface .aligned .form-row input[type="file"] {
        width: 100% !important;
    }
}

/* improve responsive selector */

/* fix [stacked, not-stacked] equalize horizontal and vertical select padding for selector */
.admin-interface .selector .selector-available select,
.admin-interface .selector .selector-chosen select {
    padding: 7px 10px;
    display: block;
}

/* fix [stacked, not-stacked] select options text overflow */
.admin-interface .selector .selector-available select option,
.admin-interface .selector .selector-chosen select option {
    overflow: hidden;
    text-overflow: ellipsis;
}

/* fix [not-stacked] equalize selectors height by adding the height of the .selector-available filter-bar */
.admin-interface .selector:not(.stacked) .selector-chosen select {
    height: calc(46px + 17.2em) !important;
}
