/*
django-tabbed-admin support
https://github.com/omji/django-tabbed-admin
*/

/* Hide tabs until ready */
/*
.admin-interface #tabs ul {
    display: none;
}

.admin-interface #tabs ul.ui-tabs-nav {
    display: block;
}
*/

.admin-interface .ui-tabs .ui-tabs-panel[id^=tabs] .module.aligned:last-child {
    margin-bottom: 0;
}

.admin-interface .ui-tabs .ui-tabs-panel[id^=tabs] .module.aligned:last-child .form-row:last-child {
    border-bottom: none;
}

@media (max-width: 350px){
    .admin-interface .ui-tabs .ui-tabs-panel[id^=tabs] .vTextField,
    .admin-interface .inline-related .vTextField {
        width: 17em;
    }
}

@media (max-width: 767px){
    /* fix horizontal overflow - responsive.css:563 */
    .admin-interface .ui-tabs .ui-tabs-panel[id^=tabs] .aligned .form-row > div:not([class]) {
        width: 100% !important;
    }
}
